Settings class

Constructors

Settings()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

backgroundLocationEnable → Future<bool?>
no setter
isBackgroundLocationEnabled → Future<bool>
no setter

Static Methods

setBackgroundLocationEnabled(bool? enable) → Future<void>

Constants

CHANNEL_SETTINGS → const String